# Advanced Filter Options
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/advanced-filter-options#introduction)
  * [Advanced Filtering](https://help.sap.com/docs/leanix/ea/advanced-filter-options#advanced-filtering)
  * [Combining Filters with AND, OR, and IS NOT Logic](https://help.sap.com/docs/leanix/ea/advanced-filter-options#combining-filters-with-and,-or,-and-is-not-logic)
  * [Filtering by Fields on Relation](https://help.sap.com/docs/leanix/ea/advanced-filter-options#filtering-by-fields-on-relation)
  * [Inverting Applied Fields on Relation Filter](https://help.sap.com/docs/leanix/ea/advanced-filter-options#inverting-applied-fields-on-relation-filter)
  * [Making Fact Sheet Fields Available as Filter Options](https://help.sap.com/docs/leanix/ea/advanced-filter-options#making-fact-sheet-fields-available-as-filter-options)
  * [Using the Lifecycle Filter](https://help.sap.com/docs/leanix/ea/advanced-filter-options#using-the-lifecycle-filter)
  * [Filtering by Subscriptions](https://help.sap.com/docs/leanix/ea/advanced-filter-options#filtering-by-subscriptions)


View all
Advanced filter options provide powerful ways to refine searches and manage fact sheets. These options allow for complex queries, making it easier to find and organize specific architectural elements within your IT landscape.
